==> tencentcloud-sdk-python-intl-en-3.0.365.tar.gz: tencentcloud-sdk-python-intl-en-3.0.365/tencentcloud/mdc/v20200828/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Internal error.
INTERNALERROR = 'InternalError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# The quantity exceeds the limit.
INVALIDPARAMETER_EXCEEDEDQUANTITYLIMIT = 'InvalidParameter.ExceededQuantityLimit'

# Invalid ID.
INVALIDPARAMETER_ID = 'InvalidParameter.Id'

# Invalid input.
INVALIDPARAMETER_INPUT = 'InvalidParameter.Input'

# Invalid maximum bandwidth value.
INVALIDPARAMETER_MAXBANDWIDTH = 'InvalidParameter.MaxBandwidth'

# Invalid `Name`.
INVALIDPARAMETER_NAME = 'InvalidParameter.Name'

# No information found.
INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'

# Invalid `OutputGroups` value
INVALIDPARAMETER_OUTPUTGROUPS = 'InvalidParameter.OutputGroups'

# Invalid `PageNum`.
INVALIDPARAMETER_PAGENUM = 'InvalidParameter.PageNum'

# Invalid `PageSize`.
INVALIDPARAMETER_PAGESIZE = 'InvalidParameter.PageSize'

# Unexpected status.
INVALIDPARAMETER_STATE = 'InvalidParameter.State'

==> tencentcloud-sdk-python-intl-en-3.0.503.tar.gz: tencentcloud-sdk-python-intl-en-3.0.503/tencentcloud/mdc/v20200828/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Internal error.
INTERNALERROR = 'InternalError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Invalid `EndTime`.
INVALIDPARAMETER_ENDTIME = 'InvalidParameter.EndTime'

# The quantity exceeds the limit.
INVALIDPARAMETER_EXCEEDEDQUANTITYLIMIT = 'InvalidParameter.ExceededQuantityLimit'

# Invalid ID.
INVALIDPARAMETER_ID = 'InvalidParameter.Id'

# Invalid input.
INVALIDPARAMETER_INPUT = 'InvalidParameter.Input'

# Invalid `InputOutputId`.
INVALIDPARAMETER_INPUTOUTPUTID = 'InvalidParameter.InputOutputId'

# Invalid maximum bandwidth value.
INVALIDPARAMETER_MAXBANDWIDTH = 'InvalidParameter.MaxBandwidth'

# Invalid `Name`.
INVALIDPARAMETER_NAME = 'InvalidParameter.Name'

# No information found.
INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'

# Invalid `Output`.
INVALIDPARAMETER_OUTPUT = 'InvalidParameter.Output'

# Invalid `OutputGroups` value
INVALIDPARAMETER_OUTPUTGROUPS = 'InvalidParameter.OutputGroups'

# Invalid `OutputId`.
INVALIDPARAMETER_OUTPUTID = 'InvalidParameter.OutputId'

# Invalid `PageNum`.
INVALIDPARAMETER_PAGENUM = 'InvalidParameter.PageNum'

# Invalid `PageSize`.
INVALIDPARAMETER_PAGESIZE = 'InvalidParameter.PageSize'

# Invalid `Period`.
INVALIDPARAMETER_PERIOD = 'InvalidParameter.Period'

# Invalid `Pipeline`.
INVALIDPARAMETER_PIPELINE = 'InvalidParameter.Pipeline'

# Invalid `Protocol`.
INVALIDPARAMETER_PROTOCOL = 'InvalidParameter.Protocol'

# Invalid `SortType`.
INVALIDPARAMETER_SORTTYPE = 'InvalidParameter.SortType'

# Invalid `StartTime`.
INVALIDPARAMETER_STARTTIME = 'InvalidParameter.StartTime'

# Unexpected status.
INVALIDPARAMETER_STATE = 'InvalidParameter.State'

# Invalid `Type`.
INVALIDPARAMETER_TYPE = 'InvalidParameter.Type'
